@@ -43,6 +43,7 @@ from .conf import PAGINATION_SETTINGS
 from django.db import models as m
 from django.db import connection
 from copy import deepcopy
+from .conf import db_engine
 # from rest_framework import serializers
 
 
@@ -538,16 +539,20 @@ def get_model_max_id_in_db(model):
         if ordering[0] == '-id':
             obj = model.objects.first()
             max_id = obj.id if obj else 0
-            ret = max_id + 1
+            ret = max_id + 1 if isinstance(max_id, int) else 1
             return ret
         if ordering[0] == 'id':
             obj = model.objects.last()
             max_id = obj.id if obj else 0
-            ret = max_id + 1
+            ret = max_id + 1 if isinstance(max_id, int) else 1
             return ret
     qs = model.objects.all()
-    max_id = qs.aggregate(max_id=Max('id')).get('max_id')  if qs.count() else 0
-    ret = max_id + 1
+    try:
+        max_id = qs.aggregate(max_id=Max('id')).get('max_id') if qs.count() else 0
+        ret = max_id + 1 if isinstance(max_id, int) else 1
+    except Exception as e:
+        warn(e)
+        ret = 1
     return ret
 
 
@@ -863,3 +868,30 @@ def get_statistic_fields_result(queryset, statistic_fields, statistic_size=5, de
     return statistic_dc
 
 
+class DjangoUtils:
+    @staticmethod
+    def distinct(qs_ls, fields):
+        """
+        对不同数据库的distince方法进行兼容
+        """
+        if isinstance(fields, str):
+            fields = [fields]
+        if 'postgresql' in db_engine:
+            ret = qs_ls.distinct(*fields)
+        else:
+            ret = qs_ls.distinct()
+        return ret
+
+    @staticmethod
+    def get_serializer_context_with_no_host_prefix_to_media_url(self):
+        """
+        将媒体文件的url去除host前缀
+        """
+        return {
+            'format': self.format_kwarg,
+            'view': self
+        }
+
+
+distinct = DjangoUtils.distinct
+
