@@ -293,3 +293,17 @@ def replace_path_by_platform(path):
         path = path.replace('\\', '/')
     return path
 
+
+def find_indexes_in_dc_ls(dc_ls, key, value, find_all=False):
+    indexes = []
+    for i in range(len(dc_ls)):
+        dc_i = dc_ls[i]
+        for k, v in dc_i.items():
+            if k == key and v == value:
+                indexes.append(i)
+                if not find_all:
+                    break
+    return indexes
+
+
+
